@@ -1,10 +1,12 @@
 import abc
-from typing import Any, Tuple, Union, Iterable
+from typing import Any
 from numbers import Integral
 from functools import reduce, partial
+from collections.abc import Iterable
+
+import numpy as np
 
 import astropy.units as u
-import numpy as np
 from astropy.coordinates import SkyCoord
 from astropy.time import Time
 from astropy.wcs import WCS
@@ -14,11 +16,15 @@ from astropy.wcs.wcsapi.wrappers.sliced_wcs import SlicedLowLevelWCS, sanitize_s
 
 from ndcube.utils.wcs import convert_between_array_and_pixel_axes
 from ndcube.wcs.wrappers import CompoundLowLevelWCS, ResampledLowLevelWCS
+from .table_coord import (
+    BaseTableCoordinate,
+    MultipleTableCoordinate,
+    QuantityTableCoordinate,
+    SkyCoordTableCoordinate,
+    TimeTableCoordinate,
+)
 
-from .table_coord import (BaseTableCoordinate, MultipleTableCoordinate, QuantityTableCoordinate,
-                          SkyCoordTableCoordinate, TimeTableCoordinate)
-
-__all__ = ['ExtraCoordsABC', 'ExtraCoords']
+__all__ = ['ExtraCoords', 'ExtraCoordsABC']
 
 
 class ExtraCoordsABC(abc.ABC):
@@ -41,10 +47,10 @@ class ExtraCoordsABC(abc.ABC):
     """
     @abc.abstractmethod
     def add(self,
-            name: Union[str, Iterable[str]],
-            array_dimension: Union[int, Iterable[int]],
+            name: str | Iterable[str],
+            array_dimension: int | Iterable[int],
             lookup_table: Any,
-            physical_types: Union[str, Iterable[str]] = None,
+            physical_types: str | Iterable[str] = None,
             **kwargs):
         """
         Add a coordinate to this `~ndcube.ExtraCoords` based on a lookup table.
@@ -73,7 +79,7 @@ class ExtraCoordsABC(abc.ABC):
 
     @property
     @abc.abstractmethod
-    def mapping(self) -> Iterable[Tuple[int, int]]:
+    def mapping(self) -> Iterable[tuple[int, int]]:
         """
         The mapping between the array dimensions and pixel dimensions.
 
@@ -103,7 +109,7 @@ class ExtraCoordsABC(abc.ABC):
         """Return True if no extra coords present, else return False."""
 
     @abc.abstractmethod
-    def __getitem__(self, item: Union[str, int, slice, Iterable[Union[str, int, slice]]]) -> "ExtraCoordsABC":
+    def __getitem__(self, item: str | int | slice | Iterable[str | int | slice]) -> "ExtraCoordsABC":
         """
         ExtraCoords can be sliced with either a string, or a numpy like slice.
 
@@ -143,8 +149,8 @@ class ExtraCoords(ExtraCoordsABC):
 
         # Lookup tables is a list of (pixel_dim, LookupTableCoord) to allow for
         # one pixel dimension having more than one lookup coord.
-        self._lookup_tables = list()
-        self._dropped_tables = list()
+        self._lookup_tables = []
+        self._dropped_tables = []
 
         # We need a reference to the parent NDCube
         self._ndcube = ndcube
@@ -224,8 +230,8 @@ class ExtraCoords(ExtraCoordsABC):
         self._lookup_tables.append((array_dimension, coord))
 
         # Sort the LUTs so that the mapping and the wcs are ordered in pixel dim order
-        self._lookup_tables = list(sorted(self._lookup_tables,
-                                          key=lambda x: x[0] if isinstance(x[0], Integral) else x[0][0]))
+        self._lookup_tables = sorted(self._lookup_tables,
+                                          key=lambda x: x[0] if isinstance(x[0], Integral) else x[0][0])
 
     @property
     def _name_lut_map(self):
@@ -237,7 +243,7 @@ class ExtraCoords(ExtraCoordsABC):
     def keys(self):
         # docstring in ABC
         if not self.wcs:
-            return tuple()
+            return ()
 
         return tuple(self.wcs.world_axis_names) if self.wcs.world_axis_names else None
 
@@ -250,12 +256,12 @@ class ExtraCoords(ExtraCoordsABC):
         # If mapping is not set but lookup_tables is empty then the extra
         # coords is empty, so there is no mapping.
         if not self._lookup_tables:
-            return tuple()
+            return ()
 
         # The mapping is from the array index (position in the list) to the
         # pixel dimensions (numbers in the list)
         lts = [list([lt[0]] if isinstance(lt[0], Integral) else lt[0]) for lt in self._lookup_tables]
-        converter = partial(convert_between_array_and_pixel_axes, naxes=len(self._ndcube.dimensions))
+        converter = partial(convert_between_array_and_pixel_axes, naxes=len(self._ndcube.shape))
         pixel_indicies = [list(converter(np.array(ids))) for ids in lts]
         return tuple(reduce(list.__add__, pixel_indicies))
 
@@ -286,7 +292,7 @@ class ExtraCoords(ExtraCoordsABC):
         if not self._lookup_tables:
             return None
 
-        tcoords = set(lt[1] for lt in self._lookup_tables)
+        tcoords = {lt[1] for lt in self._lookup_tables}
         # created a sorted list of unique items
         _tmp = set()  # a temporary set
         tcoords = [x[1] for x in self._lookup_tables if x[1] not in _tmp and _tmp.add(x[1]) is None]
@@ -317,8 +323,7 @@ class ExtraCoords(ExtraCoordsABC):
         # docstring in ABC
         if not self._wcs and not self._lookup_tables:
             return True
-        else:
-            return False
+        return False
 
     def _getitem_string(self, item):
         """
@@ -396,7 +401,7 @@ class ExtraCoords(ExtraCoordsABC):
         if self._wcs:
             return self._getitem_wcs(item)
 
-        elif self._lookup_tables:
+        if self._lookup_tables:
             return self._getitem_lookup_tables(item)
 
         # If we get here this object is empty, so just return an empty extra coords
@@ -419,7 +424,7 @@ class ExtraCoords(ExtraCoordsABC):
 
             return mtc.dropped_world_dimensions
 
-        return dict()
+        return {}
 
     def resample(self, factor, offset=0, ndcube=None, **kwargs):
         """
@@ -521,7 +526,7 @@ class ExtraCoords(ExtraCoordsABC):
     @property
     def _cube_array_axes_without_extra_coords(self):
         """Return the array axes not associated with any extra coord."""
-        return set(range(len(self._ndcube.dimensions))) - set(self.mapping)
+        return set(range(len(self._ndcube.shape))) - set(self.mapping)
 
     def __str__(self):
         classname = self.__class__.__name__
